@@ -14,6 +14,16 @@ class Logger:
       txt = [str(t) for t in txt]
       f.write(','.join(txt) + '\n')
 
+  def logInfoWithTimestamp(self, filename:str, *txt):
+    with open(filename, 'a') as f:
+      txt = [str(t) for t in txt]
+      f.write('[INFO] ' + now().strftime('%Y-%m-%d %X') + ' - ' + ' '.join(txt) + '\n')
+
+  def logErrorWithTimestamp(self, filename:str, *txt):
+    with open(filename, 'a') as f:
+      txt = [str(t) for t in txt]
+      f.write('[ERROR] ' + now().strftime('%Y-%m-%d %X') + ' - ' + ' '.join(txt) + '\n')
+
   def writeToFile(self, filename:str, txt:str):
     with open(filename, 'w') as f:
       f.write(txt)
@@ -21,7 +31,7 @@ class Logger:
   def info(self, *txt):
     txt = [str(t) for t in txt]
     print('[INFO]', now().strftime('%Y-%m-%d %X'), '-', ' '.join(txt))
-    
+
   def error(self, *txt):
     txt = [str(t) for t in txt]
     print('[ERROR]', now().strftime('%Y-%m-%d %X'), '-', ' '.join(txt))
